==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebForOfDataChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfDataChangingEventArgsDetailDescriptionMetadata } from "./WebForOfDataChangingEventArgsDetailDescriptionMetadata";
import { WebForOfDataChangingEventArgsDescription } from "./WebForOfDataChangingEventArgsDescription";
/**
 * @hidden
 */
var WebForOfDataChangingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebForOfDataChangingEventArgsDescriptionMetadata, _super);
    function WebForOfDataChangingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfDataChangingEventArgsDescriptionMetadata.b = function (a) {
        if (WebForOfDataChangingEventArgsDescriptionMetadata.a == null) {
            WebForOfDataChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfDataChangingEventArgsDescriptionMetadata.c(WebForOfDataChangingEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebForOfDataChangingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebForOfDataChangingEventArgsDescriptionMetadata.a);
        WebForOfDataChangingEventArgsDetailDescriptionMetadata.d(a);
    };
    WebForOfDataChangingEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ForOfDataChangingEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebForOfDataChangingEventArgsDetail");
    };
    WebForOfDataChangingEventArgsDescriptionMetadata.d = function (a) {
        WebForOfDataChangingEventArgsDescriptionMetadata.b(a);
        a.ad("WebForOfDataChangingEventArgs", function () { return new WebForOfDataChangingEventArgsDescription(); });
        a.ac("WebForOfDataChangingEventArgs", WebForOfDataChangingEventArgsDescriptionMetadata.a);
    };
    WebForOfDataChangingEventArgsDescriptionMetadata.$t = markType(WebForOfDataChangingEventArgsDescriptionMetadata, 'WebForOfDataChangingEventArgsDescriptionMetadata');
    WebForOfDataChangingEventArgsDescriptionMetadata.a = null;
    return WebForOfDataChangingEventArgsDescriptionMetadata;
}(Base));
export { WebForOfDataChangingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebForOfDataChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfDataChangingEventArgsDetailDescriptionMetadata } from "./WebForOfDataChangingEventArgsDetailDescriptionMetadata";
import { WebForOfDataChangingEventArgsDescription } from "./WebForOfDataChangingEventArgsDescription";
/**
 * @hidden
 */
var WebForOfDataChangingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebForOfDataChangingEventArgsDescriptionMetadata, _super);
    function WebForOfDataChangingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfDataChangingEventArgsDescriptionMetadata.b = function (a) {
        if (WebForOfDataChangingEventArgsDescriptionMetadata.a == null) {
            WebForOfDataChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfDataChangingEventArgsDescriptionMetadata.c(WebForOfDataChangingEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebForOfDataChangingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebForOfDataChangingEventArgsDescriptionMetadata.a);
        WebForOfDataChangingEventArgsDetailDescriptionMetadata.d(a);
    };
    WebForOfDataChangingEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ForOfDataChangingEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebForOfDataChangingEventArgsDetail");
    };
    WebForOfDataChangingEventArgsDescriptionMetadata.d = function (a) {
        WebForOfDataChangingEventArgsDescriptionMetadata.b(a);
        a.ae("WebForOfDataChangingEventArgs", function () { return new WebForOfDataChangingEventArgsDescription(); });
        a.ad("WebForOfDataChangingEventArgs", WebForOfDataChangingEventArgsDescriptionMetadata.a);
    };
    WebForOfDataChangingEventArgsDescriptionMetadata.$t = markType(WebForOfDataChangingEventArgsDescriptionMetadata, 'WebForOfDataChangingEventArgsDescriptionMetadata');
    WebForOfDataChangingEventArgsDescriptionMetadata.a = null;
    return WebForOfDataChangingEventArgsDescriptionMetadata;
}(Base));
export { WebForOfDataChangingEventArgsDescriptionMetadata };
